===================
Support and Contact
===================

* The ``#pimutils`` IRC channel on Freenode might be active, depending on
  your timezone. Use it for support and general (including off-topic)
  discussion.

* Open `a GitHub issue <https://github.com/pimutils/vdirsyncer/issues/>`_ for
  concrete bug reports and feature requests.

* Lastly, you can also `contact the author directly
  <https://unterwaditzer.net/contact.html>`_.
